==> zio-aws-appsync_2.13-6.20.74.2-sources.jar: zio/aws/appsync/model/ListSourceApiAssociationsRequest.scala <==
package zio.aws.appsync.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.appsync.model.primitives.{MaxResults, PaginationToken}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListSourceApiAssociationsRequest(
    apiId: String,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest = {
    import ListSourceApiAssociationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.appsync.model.ListSourceApiAssociationsRequest.ReadOnly =
    zio.aws.appsync.model.ListSourceApiAssociationsRequest.wrap(buildAwsValue())
}
object ListSourceApiAssociationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.ListSourceApiAssociationsRequest =
      zio.aws.appsync.model.ListSourceApiAssociationsRequest(
        apiId,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def apiId: String
    def nextToken: Optional[PaginationToken]
    def maxResults: Optional[MaxResults]
    def getApiId: ZIO[Any, Nothing, String] = ZIO.succeed(apiId)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
  ) extends zio.aws.appsync.model.ListSourceApiAssociationsRequest.ReadOnly {
    override val apiId: String = impl.apiId(): String
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.appsync.model.primitives.PaginationToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.appsync.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
  ): zio.aws.appsync.model.ListSourceApiAssociationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-appsync_3-6.20.120.1-sources.jar: zio/aws/appsync/model/ListSourceApiAssociationsRequest.scala <==
package zio.aws.appsync.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.appsync.model.primitives.{MaxResults, PaginationToken}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListSourceApiAssociationsRequest(
    apiId: String,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest = {
    import ListSourceApiAssociationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.appsync.model.ListSourceApiAssociationsRequest.ReadOnly =
    zio.aws.appsync.model.ListSourceApiAssociationsRequest.wrap(buildAwsValue())
}
object ListSourceApiAssociationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.ListSourceApiAssociationsRequest =
      zio.aws.appsync.model.ListSourceApiAssociationsRequest(
        apiId,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def apiId: String
    def nextToken: Optional[PaginationToken]
    def maxResults: Optional[MaxResults]
    def getApiId: ZIO[Any, Nothing, String] = ZIO.succeed(apiId)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
  ) extends zio.aws.appsync.model.ListSourceApiAssociationsRequest.ReadOnly {
    override val apiId: String = impl.apiId(): String
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.appsync.model.primitives.PaginationToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.appsync.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.ListSourceApiAssociationsRequest
  ): zio.aws.appsync.model.ListSourceApiAssociationsRequest.ReadOnly =
    new Wrapper(impl)
}
